Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(583)

Unified Diff: components/search_provider_logos/logo_tracker.h

Issue 2760003002: [Home] Use white doodle background when Chrome Home is enabled (Closed)
Patch Set: [Home] Use white doodle background when Chrome Home is enabled Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/search_provider_logos/logo_tracker.h
diff --git a/components/search_provider_logos/logo_tracker.h b/components/search_provider_logos/logo_tracker.h
index 851e1bc5a03479e817241e561888bf17feaf0c57..10e033c0d0e15dd89b90762a381a44b99f59e455 100644
--- a/components/search_provider_logos/logo_tracker.h
+++ b/components/search_provider_logos/logo_tracker.h
@@ -80,7 +80,8 @@ typedef base::Callback<std::unique_ptr<EncodedLogo>(
typedef base::Callback<GURL(const GURL& logo_url,
const std::string& fingerprint,
bool wants_cta,
- bool transparent)> AppendQueryparamsToLogoURL;
+ bool gray_background)>
+ AppendQueryparamsToLogoURL;
// This class provides the logo for a search provider. Logos are downloaded from
// the search provider's logo URL and cached on disk.
@@ -124,7 +125,8 @@ class LogoTracker : public net::URLFetcherDelegate {
// server's response into a EncodedLogo object. |append_queryparams_func| is a
// callback that will return the URL from which to download the logo.
// |wants_cta| determines if the url should return a call to action image.
- // |transparent| determines whether to request a transparent logo.
+ // |gray_background| determines whether to request a logo with a gray
+ // background. The gray will match the NTP background color.
// Note: |parse_logo_response_func| and |append_queryparams_func| must be
// suitable for running multiple times, concurrently, and on multiple threads.
// TODO(ianwen): remove wants_cta from parameter.
@@ -132,7 +134,7 @@ class LogoTracker : public net::URLFetcherDelegate {
const ParseLogoResponse& parse_logo_response_func,
const AppendQueryparamsToLogoURL& append_queryparams_func,
bool wants_cta,
- bool transparent);
+ bool gray_background);
// Retrieves the current search provider's logo from the local cache and/or
// over the network, and registers |observer| to be called when the cached
@@ -220,8 +222,8 @@ class LogoTracker : public net::URLFetcherDelegate {
// If |true| request call to action in server API.
bool wants_cta_;
- // If |true| request transparent doodle.
- bool transparent_;
+ // If |true| request a doodle with a gray background.
+ bool gray_background_;
// False if an asynchronous task is currently running.
bool is_idle_;
« no previous file with comments | « components/search_provider_logos/google_logo_api.cc ('k') | components/search_provider_logos/logo_tracker.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698